/*******************************************************************************
* File Name: RSET.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_RSET_H) /* Pins RSET_H */
#define CY_PINS_RSET_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "RSET_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 RSET__PORT == 15 && ((RSET__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    RSET_Write(uint8 value);
void    RSET_SetDriveMode(uint8 mode);
uint8   RSET_ReadDataReg(void);
uint8   RSET_Read(void);
void    RSET_SetInterruptMode(uint16 position, uint16 mode);
uint8   RSET_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the RSET_SetDriveMode() function.
     *  @{
     */
        #define RSET_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define RSET_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define RSET_DM_RES_UP          PIN_DM_RES_UP
        #define RSET_DM_RES_DWN         PIN_DM_RES_DWN
        #define RSET_DM_OD_LO           PIN_DM_OD_LO
        #define RSET_DM_OD_HI           PIN_DM_OD_HI
        #define RSET_DM_STRONG          PIN_DM_STRONG
        #define RSET_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define RSET_MASK               RSET__MASK
#define RSET_SHIFT              RSET__SHIFT
#define RSET_WIDTH              1u

/* Interrupt constants */
#if defined(RSET__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in RSET_SetInterruptMode() function.
     *  @{
     */
        #define RSET_INTR_NONE      (uint16)(0x0000u)
        #define RSET_INTR_RISING    (uint16)(0x0001u)
        #define RSET_INTR_FALLING   (uint16)(0x0002u)
        #define RSET_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define RSET_INTR_MASK      (0x01u) 
#endif /* (RSET__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define RSET_PS                     (* (reg8 *) RSET__PS)
/* Data Register */
#define RSET_DR                     (* (reg8 *) RSET__DR)
/* Port Number */
#define RSET_PRT_NUM                (* (reg8 *) RSET__PRT) 
/* Connect to Analog Globals */                                                  
#define RSET_AG                     (* (reg8 *) RSET__AG)                       
/* Analog MUX bux enable */
#define RSET_AMUX                   (* (reg8 *) RSET__AMUX) 
/* Bidirectional Enable */                                                        
#define RSET_BIE                    (* (reg8 *) RSET__BIE)
/* Bit-mask for Aliased Register Access */
#define RSET_BIT_MASK               (* (reg8 *) RSET__BIT_MASK)
/* Bypass Enable */
#define RSET_BYP                    (* (reg8 *) RSET__BYP)
/* Port wide control signals */                                                   
#define RSET_CTL                    (* (reg8 *) RSET__CTL)
/* Drive Modes */
#define RSET_DM0                    (* (reg8 *) RSET__DM0) 
#define RSET_DM1                    (* (reg8 *) RSET__DM1)
#define RSET_DM2                    (* (reg8 *) RSET__DM2) 
/* Input Buffer Disable Override */
#define RSET_INP_DIS                (* (reg8 *) RSET__INP_DIS)
/* LCD Common or Segment Drive */
#define RSET_LCD_COM_SEG            (* (reg8 *) RSET__LCD_COM_SEG)
/* Enable Segment LCD */
#define RSET_LCD_EN                 (* (reg8 *) RSET__LCD_EN)
/* Slew Rate Control */
#define RSET_SLW                    (* (reg8 *) RSET__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define RSET_PRTDSI__CAPS_SEL       (* (reg8 *) RSET__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define RSET_PRTDSI__DBL_SYNC_IN    (* (reg8 *) RSET__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define RSET_PRTDSI__OE_SEL0        (* (reg8 *) RSET__PRTDSI__OE_SEL0) 
#define RSET_PRTDSI__OE_SEL1        (* (reg8 *) RSET__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define RSET_PRTDSI__OUT_SEL0       (* (reg8 *) RSET__PRTDSI__OUT_SEL0) 
#define RSET_PRTDSI__OUT_SEL1       (* (reg8 *) RSET__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define RSET_PRTDSI__SYNC_OUT       (* (reg8 *) RSET__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(RSET__SIO_CFG)
    #define RSET_SIO_HYST_EN        (* (reg8 *) RSET__SIO_HYST_EN)
    #define RSET_SIO_REG_HIFREQ     (* (reg8 *) RSET__SIO_REG_HIFREQ)
    #define RSET_SIO_CFG            (* (reg8 *) RSET__SIO_CFG)
    #define RSET_SIO_DIFF           (* (reg8 *) RSET__SIO_DIFF)
#endif /* (RSET__SIO_CFG) */

/* Interrupt Registers */
#if defined(RSET__INTSTAT)
    #define RSET_INTSTAT            (* (reg8 *) RSET__INTSTAT)
    #define RSET_SNAP               (* (reg8 *) RSET__SNAP)
    
	#define RSET_0_INTTYPE_REG 		(* (reg8 *) RSET__0__INTTYPE)
#endif /* (RSET__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_RSET_H */


/* [] END OF FILE */
