/*******************************************************************************
* File Name: nCS.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_nCS_H) /* Pins nCS_H */
#define CY_PINS_nCS_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "nCS_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 nCS__PORT == 15 && ((nCS__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    nCS_Write(uint8 value);
void    nCS_SetDriveMode(uint8 mode);
uint8   nCS_ReadDataReg(void);
uint8   nCS_Read(void);
void    nCS_SetInterruptMode(uint16 position, uint16 mode);
uint8   nCS_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the nCS_SetDriveMode() function.
     *  @{
     */
        #define nCS_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define nCS_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define nCS_DM_RES_UP          PIN_DM_RES_UP
        #define nCS_DM_RES_DWN         PIN_DM_RES_DWN
        #define nCS_DM_OD_LO           PIN_DM_OD_LO
        #define nCS_DM_OD_HI           PIN_DM_OD_HI
        #define nCS_DM_STRONG          PIN_DM_STRONG
        #define nCS_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define nCS_MASK               nCS__MASK
#define nCS_SHIFT              nCS__SHIFT
#define nCS_WIDTH              1u

/* Interrupt constants */
#if defined(nCS__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in nCS_SetInterruptMode() function.
     *  @{
     */
        #define nCS_INTR_NONE      (uint16)(0x0000u)
        #define nCS_INTR_RISING    (uint16)(0x0001u)
        #define nCS_INTR_FALLING   (uint16)(0x0002u)
        #define nCS_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define nCS_INTR_MASK      (0x01u) 
#endif /* (nCS__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define nCS_PS                     (* (reg8 *) nCS__PS)
/* Data Register */
#define nCS_DR                     (* (reg8 *) nCS__DR)
/* Port Number */
#define nCS_PRT_NUM                (* (reg8 *) nCS__PRT) 
/* Connect to Analog Globals */                                                  
#define nCS_AG                     (* (reg8 *) nCS__AG)                       
/* Analog MUX bux enable */
#define nCS_AMUX                   (* (reg8 *) nCS__AMUX) 
/* Bidirectional Enable */                                                        
#define nCS_BIE                    (* (reg8 *) nCS__BIE)
/* Bit-mask for Aliased Register Access */
#define nCS_BIT_MASK               (* (reg8 *) nCS__BIT_MASK)
/* Bypass Enable */
#define nCS_BYP                    (* (reg8 *) nCS__BYP)
/* Port wide control signals */                                                   
#define nCS_CTL                    (* (reg8 *) nCS__CTL)
/* Drive Modes */
#define nCS_DM0                    (* (reg8 *) nCS__DM0) 
#define nCS_DM1                    (* (reg8 *) nCS__DM1)
#define nCS_DM2                    (* (reg8 *) nCS__DM2) 
/* Input Buffer Disable Override */
#define nCS_INP_DIS                (* (reg8 *) nCS__INP_DIS)
/* LCD Common or Segment Drive */
#define nCS_LCD_COM_SEG            (* (reg8 *) nCS__LCD_COM_SEG)
/* Enable Segment LCD */
#define nCS_LCD_EN                 (* (reg8 *) nCS__LCD_EN)
/* Slew Rate Control */
#define nCS_SLW                    (* (reg8 *) nCS__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define nCS_PRTDSI__CAPS_SEL       (* (reg8 *) nCS__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define nCS_PRTDSI__DBL_SYNC_IN    (* (reg8 *) nCS__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define nCS_PRTDSI__OE_SEL0        (* (reg8 *) nCS__PRTDSI__OE_SEL0) 
#define nCS_PRTDSI__OE_SEL1        (* (reg8 *) nCS__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define nCS_PRTDSI__OUT_SEL0       (* (reg8 *) nCS__PRTDSI__OUT_SEL0) 
#define nCS_PRTDSI__OUT_SEL1       (* (reg8 *) nCS__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define nCS_PRTDSI__SYNC_OUT       (* (reg8 *) nCS__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(nCS__SIO_CFG)
    #define nCS_SIO_HYST_EN        (* (reg8 *) nCS__SIO_HYST_EN)
    #define nCS_SIO_REG_HIFREQ     (* (reg8 *) nCS__SIO_REG_HIFREQ)
    #define nCS_SIO_CFG            (* (reg8 *) nCS__SIO_CFG)
    #define nCS_SIO_DIFF           (* (reg8 *) nCS__SIO_DIFF)
#endif /* (nCS__SIO_CFG) */

/* Interrupt Registers */
#if defined(nCS__INTSTAT)
    #define nCS_INTSTAT            (* (reg8 *) nCS__INTSTAT)
    #define nCS_SNAP               (* (reg8 *) nCS__SNAP)
    
	#define nCS_0_INTTYPE_REG 		(* (reg8 *) nCS__0__INTTYPE)
#endif /* (nCS__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_nCS_H */


/* [] END OF FILE */
