#include "rfm22b.h"
#include "project.h"
uint8 byteCount = 2; 
typedef enum {
  RATE_24K,
  RATE_48K,
  RATE_12K,
  RATE_96K
} RF22_RATE_mode;

const unsigned char tx_buf[17] = {0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x3b, 0x3c, 0x3d, 0x3e, 0x3f, 0x78}; // ch8  is 140


#define PACKET_LENGTH			30

#define RF22_PWRSTATE_READY		01
#define RF22_PWRSTATE_TX		0x09
#define RF22_PWRSTATE_RX		05
#define RF22_PWRSTATE_POWERDOWN		00

#define RF22_PACKET_SENT_INTERRUPT	04
#define RF22_Tx_almost_empty_interrupt	0x20
#define RF22_Rx_almost_full_interrupt   0x10
#define RF22_Rx_packet_received_interrupt   0x02


#define R315		0
#define R434		1
#define R869		2
#define R915		3

#define rx_normal 		0
#define rx_test			1
#define tx_normal 	2
#define tx_test 		3

#define tx_mode		(mode == tx_normal)||(mode == tx_test)

unsigned char 	err_byte;
unsigned int 		total_byte ;
signed char temperature_value;

unsigned char mode;
unsigned char power;
RF22_RATE_mode rate;
unsigned char band;
unsigned char fixlength;

unsigned char ItStatus1, ItStatus2;

unsigned char RF_RXBUF[64];

FlagType	                Flag;


void option_sel(void)
{
  mode = tx_normal,
  band = R434;
  rate = RATE_12K;
  Flag.PH_FIFO = 1;
  if ((mode == tx_test) || (mode == rx_test)) {
    Flag.PH_FIFO = 0;
  }
  fixlength = 0;
  power |= 0x0F;  // set to the min power, and ina_sw = 1;
  //power |= 0x0C;
}

u8 rec_message(u8* p_data)
{
  unsigned char  i, ret, chksum;

  ret = 0;
  if (!nIRQ0_READ()) {
    ItStatus1 = spim_readtx(0x03);											//read the Interrupt Status1 register
    ItStatus2 =   spim_readtx(0x04);
    ret = spim_readtx(0x3E);
    send_read_address(0x7f);
    for (i = 0; i < ret; i++) {
      RF_RXBUF[i] = read_8bit_data();
    }
    for (i = 0; i < ret; i++) {
      p_data[i] = RF_RXBUF[i];
    }
    rx_reset();
  }
  return ret;
}


void RF22_init_parameter(void)
{

  init_spi();
  option_sel();

  software_reset();

  ItStatus1 =   spim_readtx(0x03);	// read status, clear interrupt
  ItStatus2 =   spim_readtx(0x04);
 
uint8 buf[2]={0x06, 0x00};  // no wakeup up, lbd,
SPIM_PutArray(buf, byteCount);

uint8 buf1[2]={0x07, RF22_PWRSTATE_READY}; // disable lbd, wakeup timer, use internal 32768,xton = 1; in ready mode
SPIM_PutArray(buf1, byteCount);

uint8 buf2[2]={0x09, 0x7f};  // c = 12.5p
SPIM_PutArray(buf2, byteCount);

uint8 buf3[2]={0x0a, 0x05}; 
SPIM_PutArray(buf3, byteCount);
  // spi_write(0x0b, 0xf4); // gpio0 for received data output

uint8 buf4[2]={0x0b, 0xf8}; // gpio0 for received data output
SPIM_PutArray(buf4, byteCount);

uint8 buf5[2]={0x0c, 0xef};  // gpio 1 for clk output   //spi_write(0x0d, 0xfd);  // gpio 2 micro-controller clk output
SPIM_PutArray(buf5, byteCount);

uint8 buf6[2]={0x0d, 0xf8}; // gpio 2 micro-controller clk output
SPIM_PutArray(buf6, byteCount);

 
uint8 buf7[2]={0x0e, 0x00};  // gpio  0, 1,2 NO OTHER FUNCTION.
SPIM_PutArray(buf7, byteCount);

uint8 buf8[2]={0x70, 0x20};  // disable manchest
SPIM_PutArray(buf8, byteCount);

uint8 buf9[2]={0x1d, 0x40}; 
SPIM_PutArray(buf9, byteCount); // enable afc

  switch (rate)
  {
    case RATE_12K:  // 1.2k
      {
uint8 buff[2]={0x1c, 0x1d}; 
SPIM_PutArray(buff, byteCount); // 

uint8 buff1[2]={0x20, 0x83}; 
SPIM_PutArray(buff1, byteCount); //0x20 calculate from the datasheet  = 500*(1+2*down3_bypass)/(2^ndec*RB*(1+enmanch))
       
uint8 buff2[2]={0x21, 0xc0}; 
SPIM_PutArray(buff2, byteCount); // 0x21 , rxosr[10--8] = 0; stalltr = 0; (default), ccoff[19:16] = 0;
     
uint8 buff3[2]={0x22, 0x13}; 
SPIM_PutArray(buff3, byteCount); // 0x22  ncoff =5033 = 0x13a9
    
uint8 buff4[2]={0x23, 0xa9}; 
SPIM_PutArray(buff4, byteCount);  // 0x23
  
uint8 buff5[2]={0x24, 0x00}; 
SPIM_PutArray(buff5, byteCount);  // 0x24
  
uint8 buff6[2]={0x25, 0x03}; 
SPIM_PutArray(buff6, byteCount);  // 0x25

uint8 buff7[2]={0x2a, 0x1e}; 
SPIM_PutArray(buff7, byteCount); //for ook

uint8 buff8[2]={0x2c, 0x2c}; 
SPIM_PutArray(buff8, byteCount); //     
   
uint8 buff9[2]={0x2d, 0x11}; 
SPIM_PutArray(buff9, byteCount); //    
     
uint8 buff10[2]={0x2e, 0x2A}; 
SPIM_PutArray(buff10, byteCount); //tx data rate 

uint8 buff11[2]={0x6e, 0x09}; 
SPIM_PutArray(buff11, byteCount); //  
     
uint8 buff12[2]={0x6f, 0xd5}; 
SPIM_PutArray(buff12, byteCount); //      
   
        break;
      }
    case RATE_24K: // 2.4k
      {
uint8 buffe[2]={0x1c, 0x1d}; 
SPIM_PutArray(buffe, byteCount);
 
uint8 buffe1[2]={0x20, 0x41}; //0x20 calculate from the datasheet  = 500*(1+2*down3_bypass)/(2^ndec*RB*(1+enmanch))
SPIM_PutArray(buffe1, byteCount);

 uint8 buffe2[2]={0x21, 0x60};  // 0x21 , rxosr[10--8] = 0; stalltr = (default), ccoff[19:16] = 0;
SPIM_PutArray(buffe2, byteCount);      
       
 uint8 buffe3[2]={0x22, 0x27};  // 0x22  ncoff =5033 = 0x13a9
SPIM_PutArray(buffe3, byteCount);      
        
uint8 buffe4[2]={0x23, 0x52}; // 0x23
SPIM_PutArray(buffe4, byteCount);      
      
uint8 buffe5[2]={0x24, 0x00}; // 0x24
SPIM_PutArray(buffe5, byteCount);       
     
 uint8 buffe6[2]={0x25, 0x06};  // 0x25
SPIM_PutArray(buffe6, byteCount);      
        
  uint8 buffe7[2]={0x2a, 0x1e};  //for ook
SPIM_PutArray(buffe7, byteCount);    

 uint8 buffe8[2]={0x2c, 0x2A}; 
SPIM_PutArray(buffe8, byteCount);     
     
  uint8 buffe9[2]={0x2d, 0x08}; 
SPIM_PutArray(buffe9, byteCount);
  
 uint8 buffe10[2]={0x2e, 0x2A};  //tx date rate
SPIM_PutArray(buffe10, byteCount);      
           
uint8 buffe11[2]={0x6e, 0x13}; 
SPIM_PutArray(buffe11, byteCount);       
        
 uint8 buffe12[2]={0x6f, 0xa9}; 
SPIM_PutArray(buffe12, byteCount);     
   
        break;
      }
    case RATE_48K: // 4.8k
      {
uint8 buffer[2]={0x1c, 0x1d}; 
SPIM_PutArray(buffer, byteCount);  
 
uint8 buffer1[2]={0x20, 0xa1};    //0x20 calculate from the datasheet  = 500*(1+2*down3_bypass)/(2^ndec*RB*(1+enmanch))
SPIM_PutArray(buffer1, byteCount);  

uint8 buffer2[2]={0x21, 0x20};  // 0x21 , rxosr[10--8] = 0; stalltr = (default), ccoff[19:16] = 0;
SPIM_PutArray(buffer2, byteCount);  

uint8 buffer3[2]={0x22, 0x4e}; // 0x22  ncoff =5033 = 0x13a9
SPIM_PutArray(buffer3, byteCount); 

uint8 buffer4[2]={0x23, 0xa5}; // 0x23
SPIM_PutArray(buffer4, byteCount); 

uint8 buffer5[2]={0x24, 0x00}; // 0x24
SPIM_PutArray(buffer5, byteCount); 

uint8 buffer6[2]={0x25, 0x13}; // 0x25
SPIM_PutArray(buffer6, byteCount); 

uint8 buffer7[2]={0x2a, 0x1e}; 
SPIM_PutArray(buffer7, byteCount); 
      //for ook
      

uint8 buffer8[2]={0x2c, 0x29}; 
SPIM_PutArray(buffer8, byteCount); 
       
uint8 buffer9[2]={0x2d, 0x04}; 
SPIM_PutArray(buffer9, byteCount);         
     
uint8 buffer10[2]={0x2e, 0x29}; 
SPIM_PutArray(buffer10, byteCount);         
        //tx data rate
    
uint8 buffer11[2]={0x6e, 0x27}; 
SPIM_PutArray(buffer11, byteCount);         
        
uint8 buffer12[2]={0x6f, 0x52}; 
SPIM_PutArray(buffer12, byteCount);         
        break;
      }
    case RATE_96K: // 9.6k
      {
    
        uint8 buffer13[2]={0x1c, 0x1e}; 
SPIM_PutArray(buffer13, byteCount);    
  
        uint8 buffer14[2]={0x20, 0xd0};  //0x20 calculate from the datasheet  = 500*(1+2*down3_bypass)/(2^ndec*RB*(1+enmanch))
SPIM_PutArray(buffer14, byteCount);    

       uint8 buffer15[2]={0x21, 0x00}; // 0x21 , rxosr[10--8] = 0; stalltr = (default), ccoff[19:16] = 0;
SPIM_PutArray(buffer15, byteCount);    
       
        uint8 buffer16[2]={0x22, 0x9d};  // 0x22  ncoff =5033 = 0x13a9
SPIM_PutArray(buffer16, byteCount);    
        
        uint8 buffer17[2]={0x23, 0x49};  // 0x23
SPIM_PutArray(buffer17, byteCount);    
        
       uint8 buffer18[2]={0x24, 0x00};  // 0x24
SPIM_PutArray(buffer18, byteCount);    
        
       uint8 buffer19[2]={0x25, 0x45};  // 0x25
SPIM_PutArray(buffer19, byteCount);    
       
        uint8 buffer20[2]={0x2a, 0x20}; 
SPIM_PutArray(buffer20, byteCount);    
        //for ook
   
       uint8 buffer21[2]={0x2c, 0x28}; 
SPIM_PutArray(buffer21, byteCount);    
   
       uint8 buffer22[2]={0x2d, 0x82}; 
SPIM_PutArray(buffer22, byteCount);    
     
       uint8 buffer23[2]={0x2e, 0x29}; 
SPIM_PutArray(buffer23, byteCount);    
  
       uint8 buffer24[2]={0x6e, 0x4e}; 
SPIM_PutArray(buffer24, byteCount);    
     
uint8 buffer25[2]={0x6f, 0xa5}; 
SPIM_PutArray(buffer25, byteCount);    
        break;
      }
  }

  if (Flag.PH_FIFO)
  {
    uint8 buffer26[2]={0x30, 0x8c}; 
SPIM_PutArray(buffer26, byteCount);      // enable packet handler, msb first, enable crc,
    // 0x31 only readable //spi_write(0x32, 0xff);  // 0x32address enable for headere byte 0, 1,2,3, receive header check for byte 0, 1,2,3
   uint8 buffer27[2]={0x32, 0x00}; 
SPIM_PutArray(buffer27, byteCount);     //by vison
    //spi_write(0x33, 0x42);// header 3, 2, 1,0 used for head length, fixed packet length, synchronize word length 3, 2,
  uint8 buffer28[2]={0x33, 0x0A}; 
SPIM_PutArray(buffer28, byteCount);    

  } else {
    uint8 buffer29[2]={0x30, 0x00}; 
SPIM_PutArray(buffer29, byteCount);// enable packet handler, msb first, enable crc,
    // 0x31 only readable
   uint8 buffer30[2]={0x32, 0x00}; 
SPIM_PutArray(buffer30, byteCount); // 0x32address enable for headere byte 0, 1,2,3, receive header check for byte 0, 1,2,3
   // spi_write(0x33, 0x22);// no header check,  synchronize word length 3, 2,
  uint8 buffer31[2]={0x33, 0x02}; 
SPIM_PutArray(buffer31, byteCount);// no header check,  synchronize word length 3, 2,
  }

  //spi_write(0x34, 64);  // 64 nibble = 32byte preamble

   uint8 buffer32[2]={0x34, 0x16};  //by vison
SPIM_PutArray(buffer32, byteCount);

  uint8 buffer33[2]={0x35, 0x20}; //0x35 need to detect 20bit preamble
SPIM_PutArray(buffer33, byteCount);  

   uint8 buffer34[2]={0x36, 0x2d};  // synchronize word
SPIM_PutArray(buffer34, byteCount);

   uint8 buffer35[2]={0x37, 0xd4}; 
SPIM_PutArray(buffer35, byteCount);

   uint8 buffer36[2]={0x38, 0x00}; 
SPIM_PutArray(buffer36, byteCount);

  uint8 buffer37[2]={0x39, 0x00}; 
SPIM_PutArray(buffer37, byteCount);
  #if 0  //by vison
  spi_write(0x3a, 's');  // tx header
  spi_write(0x3b, 'o');
  spi_write(0x3c, 'n');
  spi_write(0x3d, 'g');

  spi_write(0x3f, 's'); // check hearder
  spi_write(0x40, 'o');
  spi_write(0x41, 'n');
  spi_write(0x42, 'g');
  spi_write(0x43, 0xff);  // all the bit to be checked
  spi_write(0x44, 0xff);  // all the bit to be checked
  spi_write(0x45, 0xff);  // all the bit to be checked
  spi_write(0x46, 0xff);  // all the bit to be checked
#endif
  uint8 buffer38[2]={0x3e, 19}; 
SPIM_PutArray(buffer38, byteCount); // total tx 17 byte
  //init_timing();  // 0x52, 53, 54, 55   set to default
  // 0x56 ---------0x6c  ??????????????????????????

  uint8 buffer39[2]={0x6d, power}; // set power
SPIM_PutArray(buffer39, byteCount);

  uint8 buffer40[2]={0x79, 0x0}; // no hopping
SPIM_PutArray(buffer40, byteCount);

  uint8 buffer41[2]={0x7a, 0x0};  // no hopping
SPIM_PutArray(buffer41, byteCount);

  if (mode == rx_test) {
    //LED_GREEN = 1;
      uint8 buffer42[2]={0x71, 0x02}; 
SPIM_PutArray(buffer42, byteCount);  // Gfsk, fd[8] =0, no invert for Tx/Rx data, direct mode, txclk -->gpio
  } else {
      uint8 buffer43[2]={0x71, 0x22}; 
SPIM_PutArray(buffer43, byteCount);  // Gfsk, fd[8] =0, no invert for Tx/Rx data, fifo mode, txclk -->gpio
    //spi_write(0x71, 0x21); //ook  Gfsk, fd[8] =0, no invert for Tx/Rx data, fifo mode, txclk -->gpio
  }

    uint8 buffer44[2]={0x72, 0x38};  // 35khz frequency deviation setting to 45k = 72*625
SPIM_PutArray(buffer44, byteCount);

    uint8 buffer45[2]={0x73, 0x0}; 
SPIM_PutArray(buffer45, byteCount);

    uint8 buffer46[2]={0x74, 0x0};  // no offset
SPIM_PutArray(buffer46, byteCount);

  switch (band)
  {
    case R315:
      {
      
          uint8 buffer47[2]={0x75, 0x47};  // hbsel = 0, sbsel =0 ???, fb =7
SPIM_PutArray(buffer47, byteCount);
      
          uint8 buffer48[2]={0x75, 0x47}; // 32000= 0x7d00 for 315Mhz
SPIM_PutArray(buffer48, byteCount);
    
uint8 buffer49[2]={0x77, 0x00}; 
SPIM_PutArray(buffer49, byteCount);
        break;
      }
    case R434:
      {
       
uint8 buffer50[2]={0x75, 0x77};  // hbsel = 0, sbsel =1 ???, fb = 19
SPIM_PutArray(buffer50, byteCount);
      
 uint8 buffer51[2]={0x76, 0xED};  // 25600= 0x6400 for 434Mhz 
SPIM_PutArray(buffer51, byteCount);
     
uint8 buffer52[2]={0x77, 0x80};  
SPIM_PutArray(buffer52, byteCount);

        break;
      }
    case R869:
      {

        uint8 buffer53[2]={0x75, 0x73};   // hbsel = 1, sbsel =1 ???, fb = 19 = 0x13
SPIM_PutArray(buffer53, byteCount);
       
        uint8 buffer54[2]={0x76, 0x70};   // 28800= 0x7080 for 869Mhz
SPIM_PutArray(buffer54, byteCount);
       
uint8 buffer55[2]={0x77, 0x80};  
SPIM_PutArray(buffer55, byteCount);
        break;
      }
    case R915:
      {
     
       uint8 buffer56[2]={0x75, 0x75};  // hbsel = 1, sbsel =0 ???, fb = 21 = 0x15
SPIM_PutArray(buffer56, byteCount);
        
        uint8 buffer57[2]={0x76, 0xbb};  // 48000= 0xbb80 for 915Mhz
SPIM_PutArray(buffer57, byteCount);
        
       uint8 buffer58[2]={0x77, 0x80};  
SPIM_PutArray(buffer58, byteCount);
        break;
      }

  }
}

void to_rx_mode(void)
{
  to_ready_mode();
  RXEN_LOW();
  TXEN_HIGH();
  delay_ms(50);
  rx_reset();
}


void rx_reset(void)
{
   uint8 buffer59[2]={0x07, RF22_PWRSTATE_READY};  
SPIM_PutArray(buffer59, byteCount);

  uint8 buffer60[2]={0x7e, 17};  // threshold for rx almost full, interrupt when 1 byte receive
SPIM_PutArray(buffer60, byteCount);

   uint8 buffer61[2]={0x08, 0x03};  //clear fifo disable multi packet
SPIM_PutArray(buffer61, byteCount);

 uint8 buffer62[2]={0x08, 0x00};   // clear fifo, disable multi packet
SPIM_PutArray(buffer62, byteCount);

  uint8 buffer63[2]={0x07, RF22_PWRSTATE_RX};  // to rx mode
SPIM_PutArray(buffer63, byteCount);

if (!Flag.PH_FIFO) {

      uint8 buffer64[2]={0x05, RF22_Rx_almost_full_interrupt};  
SPIM_PutArray(buffer64, byteCount);
  } else {
   
      uint8 buffer65[2]={0x05, RF22_Rx_packet_received_interrupt};  
SPIM_PutArray(buffer65, byteCount);
  }

  ItStatus1 = SPIM_ReadStatusrx(0x03);	//read the Interrupt Status1 register
  ItStatus2 = SPIM_ReadStatusrx(0x04);
}


unsigned int to_tx_mode(void)
{
  static unsigned int cnt =0;
  unsigned char i;

  to_ready_mode();
  RXEN_HIGH();
  TXEN_LOW();
  delay_ms(50);

clear_fifo();

  if (!Flag.PH_FIFO) {
    //	spi_write(0x7c, 60);  // tx almost full,

    uint8 buffer66[2]={0x7d, 30};  //  tx almost empty
SPIM_PutArray(buffer66,byteCount);

        uint8 buffer67[2]={0x3e, PACKET_LENGTH};  
SPIM_PutArray(buffer67, byteCount);
    for (i = 0; i < 58; i++) {
 
     uint8 buffer68[2]={0x7f, 0xaa};  
SPIM_PutArray(buffer68, byteCount);
    }


  uint8 buffer69[2]={0x05, RF22_Tx_almost_empty_interrupt};  
SPIM_PutArray(buffer69, byteCount);
    ItStatus1 =SPIM_ReadStatusrx(0x03);											//read the Interrupt Status1 register
    ItStatus2 =SPIM_ReadStatusrx(0x04);											//read the Interrupt Status2 register
    
    uint8 buffer70[2]={0x07, RF22_PWRSTATE_TX};  
SPIM_PutArray(buffer70, byteCount);
// to tx mode    //LED_RED  ^= 1;

    while (nIRQ0_READ());  // waiting for the transmission over

       uint8 buffer71[2]={0x7f, 0x2d};  
SPIM_PutArray(buffer71, byteCount);

       uint8 buffer72[2]={0x7f, 0xd4};  
SPIM_PutArray(buffer72, byteCount);

    for (i = 0; i < 17; i++)
    {
         uint8 buffer73[2]={0x7f, tx_buf[i]};  
SPIM_PutArray(buffer73, byteCount);
    }
   
    uint8 buffer74[2]={0x05, RF22_PACKET_SENT_INTERRUPT};  
SPIM_PutArray(buffer74, byteCount);
    ItStatus1 = SPIM_ReadStatusrx(0x03);	//read the Interrupt Status1 register
    ItStatus2 = SPIM_ReadStatusrx(0x04);
    while (nIRQ0_READ());
    //	LED_RED = 0;

    to_ready_mode();
  } else    // ph +fifo mode
  {

      uint8 buffer75[2]={0x34, 64};   // 64 nibble = 32byte preamble
SPIM_PutArray(buffer75, byteCount);

      uint8 buffer76[2]={0x3e, 17};    // total tx 17 byte
SPIM_PutArray(buffer76, byteCount);
    for (i = 0; i < 17; i++) {
   
    uint8 buffer77[2]={0x7f, tx_buf[i]};    
SPIM_PutArray(buffer77, byteCount);
    }
    
     uint8 buffer78[2]={0x05, RF22_PACKET_SENT_INTERRUPT};    
SPIM_PutArray(buffer78, byteCount);
    ItStatus1 = SPIM_ReadStatusrx(0x03);		//read the Interrupt Status1 register
    ItStatus2 =SPIM_ReadStatusrx(0x04);

       uint8 buffer79[2]={0x07, RF22_PWRSTATE_TX};    // to tx mode
SPIM_PutArray(buffer79, byteCount);
    //LED_RED  ^= 1;

    while (nIRQ0_READ());
    //	LED_RED = 0;

    to_ready_mode();

    //to_rx_mode();
  }
	return cnt++;
}

unsigned int send_message(u8* p_data,u8 num,u8 pk_fifo)
{
  static unsigned int cnt =0;
  unsigned char i;

  to_ready_mode();
  RXEN_HIGH();
  TXEN_LOW();
  delay_ms(50);

clear_fifo();


  if (pk_fifo) {
	
       uint8 buffer80[2]={0x34, 64};  // 64 nibble = 32byte preamble
SPIM_PutArray(buffer80, byteCount);
	
      uint8 buffer81[2]={0x3e, num};   // total tx 17 byte
SPIM_PutArray(buffer81, byteCount);
	  for (i = 0; i < num; i++) {
		
        uint8 buffer82[2]={0x7f, p_data[i]}; 
SPIM_PutArray(buffer82, byteCount);
	  }

    uint8 buffer83[2]={0x05, RF22_PACKET_SENT_INTERRUPT}; 
SPIM_PutArray(buffer83, byteCount);
	  ItStatus1 =SPIM_ReadStatusrx(0x03);	 //read the Interrupt Status1 register
	  ItStatus2 =SPIM_ReadStatusrx(0x04);
	
       uint8 buffer84[2]={0x07, RF22_PWRSTATE_TX};  // to tx mode   //LED_RED  ^= 1;
SPIM_PutArray(buffer84, byteCount);
	  
	  while (nIRQ0_READ());
	  //LED_RED = 0;
	  
	  to_ready_mode();
	  
	  //to_rx_mode();

  } else    // ph +fifo mode
  {
	//	spi_write(0x7c, 60);  // tx almost full,
 
        uint8 buffer85[2]={0x7d, 30};  //  tx almost empty
SPIM_PutArray(buffer85, byteCount);

  
            uint8 buffer86[2]={0x3e, PACKET_LENGTH};  
SPIM_PutArray(buffer86, byteCount);
    for (i = 0; i < 58; i++) {
      
         uint8 buffer87[2]={0x7f, 0xaa};  
SPIM_PutArray(buffer87, byteCount);
    }

      uint8 buffer88[2]={0x05, RF22_Tx_almost_empty_interrupt};  
SPIM_PutArray(buffer88, byteCount);

    ItStatus1 =SPIM_ReadStatusrx(0x03);											//read the Interrupt Status1 register
    ItStatus2 =SPIM_ReadStatusrx(0x04);											//read the Interrupt Status2 register

     uint8 buffer89[2]={0x07, RF22_PWRSTATE_TX};   // to tx mode    //LED_RED  ^= 1;
SPIM_PutArray(buffer89, byteCount);

    while (nIRQ0_READ());  // waiting for the transmission over

      uint8 buffer90[2]={0x7f, 0x2d};   
SPIM_PutArray(buffer90, byteCount);

uint8 buffer91[2]={0x7f, 0xd4};   
SPIM_PutArray(buffer91, byteCount);
    for (i = 0; i < 17; i++)
    {
          uint8 buffer92[2]={0x7f, tx_buf[i]};   
SPIM_PutArray(buffer92, byteCount);
    }
  
      uint8 buffer93[2]={0x05, RF22_PACKET_SENT_INTERRUPT};   
SPIM_PutArray(buffer93, byteCount);
    ItStatus1 = SPIM_ReadStatusrx(0x03);	//read the Interrupt Status1 register
    ItStatus2 = SPIM_ReadStatusrx(0x04);
    while (nIRQ0_READ());
    //	LED_RED = 0;

    to_ready_mode();
  }
	return cnt++;
}

void to_ready_mode(void)
{
  ItStatus1 = SPIM_ReadStatusrx(0x03);
  ItStatus2 = SPIM_ReadStatusrx(0x04);
  RXEN_HIGH();
  TXEN_HIGH();
  
 uint8 buffer94[2]={0x07, RF22_PWRSTATE_READY};   
SPIM_PutArray(buffer94, byteCount);
}

void clear_fifo(void)
{
  unsigned char i,j;
 uint8 buffer95[2]={0x08,0x03};   
SPIM_PutArray(buffer95, byteCount);

 uint8 buffer96[2]={0x08,0x00};   
SPIM_PutArray(buffer96, byteCount);
}

// spi driver

void Write8bitcommand(unsigned char command)  // keep sel to low
{
  unsigned char n = 8;

  nCS_HIGH();
  SCK_LOW();
  nCS_LOW();
  while (n--)
  {
    if (command & 0x80)
      Write1();
    else
      Write0();
    command = command << 1;
  }
  SCK_LOW();
}

unsigned char read_8bit_data(void)
{
  unsigned char Result, i;

  SCK_LOW();
  Result = 0;
  for (i = 0; i < 8; i++)
  { //read fifo data byte
    Result = Result << 1;
    SCK_HIGH();
    delay_us(1);
    if (MISO_READ())
    {
      Result |= 1;
    }

    SCK_LOW();
    delay_us(1);
  }
  return (Result);
}

void send_read_address(unsigned char i)
{
  i &= 0x7f;
  Write8bitcommand(i);
}

void send_8bit_data(unsigned char i)
{
  unsigned char n = 8;
  SCK_LOW();
  while (n--)
  {
    if (i & 0x80)
      Write1();
    else
      Write0();
    i = i << 1;
  }
  SCK_LOW();
}

void spi_write(unsigned char address, unsigned char data)
{
  address |= 0x80;
  Write8bitcommand(address);
  send_8bit_data(data);
  nCS_HIGH();
}

unsigned char spi_read(unsigned char address)
{
  unsigned char result;
  send_read_address(address);
  result = read_8bit_data();
  nCS_HIGH();
  return (result);
}

void Write0( void )
{
  SCK_LOW();
  delay_us(1);

  MOSI_LOW();
  delay_us(1);

  SCK_HIGH();
  delay_us(1);

}

void Write1( void )
{
  SCK_LOW();
  delay_us(1);

  MOSI_HIGH();
  delay_us(1);

  SCK_HIGH();
  delay_us(1);
}

/*************************************
the reset of software 
**************************************/
void software_reset(void)
{
  unsigned char j;
 
 uint8 buffer97[2]={0x07,0x80};   
SPIM_PutArray(buffer97, byteCount);
  for(j=0;j<250;j++)          //200us~600us
  {
    if(!nIRQ0_READ()){
      ItStatus1 = SPIM_ReadStatusrx(0x03);   
      ItStatus2 = SPIM_ReadStatusrx(0x04);
      break;
    }
    if(j==249){
      hardware_reset();     //hardware reset
    } 
  }
}
/*************************************
the reset of hardware
**************************************/
void hardware_reset(void)
{
  unsigned char k;

  //SDN = 1;
  RESET_HIGH();
  delay_ms(5);
  //SDN = 0;
  RESET_LOW();
  for(k=0;k<250;k++){
    if((!nIRQ0_READ())&&(k>=249)){
      break;        //
    }else if((!nIRQ0_READ())&&(k<=249)){
      delay_ms(25);   //delay some time,then re_Initialization the module
      break;
    }
  }     
}

void  temperature_reading(void)
{
 
 uint8 buffer98[2]={0x0f, 0x00};     // select temperature sensor
SPIM_PutArray(buffer98, byteCount);
 
uint8 buffer99[2]={0x10, 0x00};   // no amplify offset
SPIM_PutArray(buffer99, byteCount);
  
   uint8 buffer100[2]={0x12, 0x60};    // set temperature calibration, temperature range, 1c degree,
SPIM_PutArray(buffer100, byteCount);

  uint8 buffer101[2]={0x13, 0x1e};    // -30 offset 
SPIM_PutArray(buffer101, byteCount);

  uint8 buffer102[2]={0x0f, 0x80};    // ADC start
SPIM_PutArray(buffer102, byteCount);

  delay_ms(5);

  temperature_value = 0x0;

  while ((temperature_value & 0x80) == 0x0)
  {
    temperature_value = spi_read(0x0f);
    delay_us(2);
  }
  temperature_value = spi_read(0x11);
  temperature_value -= 40;

  delay_us(2);

  /*
    if((ItStatus1 &0x80) ==0x80)
    {
  	ItStatus1 &= 0x7f;
  	ItStatus1 += 40;
  	ItStatus1 |= 0x80;
    }
    else
    {
  	ItStatus1 -= 40;
    }
  */
}